{ ENERGY } https://en.wikipedia.org/wiki/Units_of_energy SYSTEM INTERNATIONAL: JOULE: 1 JOULE = kg * meters^2 * seconds^-2 ENERGY, WORK, HEAT WATT: 1 WATT = kg * meters^2 * seconds^-3 POWER, RADIANT FLUX CAPACITY VOLT: 1 VOLT = kg * m^2 * seconds^-3 * AMPERES^-1 ELECTRICAL POTENTIAL, VOLTAGE, EMF COULOMB: ELECTRICAL CHARGE AMP: 1 AMP = 1 COULOMB = 6.241509074 × 10^18 electrons' worth of charge US CUSTOMARY: FOOD POUND: 1 FOOT-POUND FORCE = 1.355818 JOULES = 0.0003240482791586998 FOOD CALORIES 1 FOOD CALORIE = ANCIENT: CALORIES: # # REPLACED BY THE JOULE # CALORIC THEORY OF HEAT: https://en.wikipedia.org/wiki/Calorie#Food_energy [ LARGE CALORIE, FOOD CALORIE, DIETARY CALORIES, KILOGRAM CALORIE, kcal ] ORIGINALLY DEFINED AS THE AMOUNT OF HEAT NEEDED TO RAISE THE TEMPERATURE OF ONE KILOGRAM OF WATER BY ONE DEGREE CELSIUS. 1 FOOD CALORIE (kcal) = 1000 SMALL CALORIES = 4184 JOULES 1 JOULE = (1 / 4184) * FOOD CALORIES